
# -*- coding: utf-8 -*-
import re
import sys

from pypeit.scripts.chk_edges import ChkEdges

if __name__ == '__main__':
    sys.argv[0] = re.sub(r'(-script\.pyw?|\.exe)?$', '', sys.argv[0])
    sys.exit(ChkEdges.entry_point())
